From c5ecc37a9afd8eaad3b184d97a0e532eef163b41 Mon Sep 17 00:00:00 2001
From: Lioness100 <jchickmm2@gmail.com>
Date: Sat, 30 Jul 2022 10:50:07 -0400
Subject: [PATCH] refactor(box1): prefer todo! over unimplemented!

---
 exercises/standard_library_types/box1.rs | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/exercises/standard_library_types/box1.rs b/exercises/standard_library_types/box1.rs
index 9d9237c..66cf00f 100644
--- a/exercises/standard_library_types/box1.rs
+++ b/exercises/standard_library_types/box1.rs
@@ -10,7 +10,7 @@
 // elements: the value of the current item and the next item. The last item is a value called `Nil`.
 //
 // Step 1: use a `Box` in the enum definition to make the code compile
 // Step 2: create both empty and non-empty cons lists by replacing `unimplemented!()`
 //
 // Note: the tests should not be changed
 //
@@ -33,11 +33,11 @@ fn main() {
 }
 
 pub fn create_empty_list() -> List {
-    unimplemented!()
+    todo!()
 }
 
 pub fn create_non_empty_list() -> List {
-    unimplemented!()
+    todo!()
 }
 
 #[cfg(test)]
@@ -10,7 +10,7 @@
 //
 // Step 1: use a `Box` in the enum definition to make the code compile
-// Step 2: create both empty and non-empty cons lists by replacing `unimplemented!()`
+// Step 2: create both empty and non-empty cons lists by replacing `todo!()`
 //
 // Note: the tests should not be changed